---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen vs what actually happened.

**Log**
Please include the log information for the session where you encountered this error. Logs can be found in `[path_to_your_user_directory]/freemocap_data/logs_info_and_settings/logs` or copy and pasted from the terminal. Include as much context as possible so we can see upstream errors.

**Environment Information:**
 - OS: [e.g. Windows 11]
 - Python Version: [e.g. 3.11]
 - Freemocap Version: [e.g. 1.2.2, displayed on home screen of the GUI]
 - Are you running `freemocap` in a virtual environment?: [yes/no -> IF `NO` - [Please do that and try again](https://freemocap.github.io/documentation/installation.html#detailed-installation-instructions)]
 - Blender Version (If applicable): [e.g. 3.6]


**Additional context**
Add any other context about the problem here.
